@@ -9,6 +9,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .HoleMag import HoleMag
 
 # Import all class method
@@ -28,35 +31,20 @@ try:
 except ImportError as error:
     comp_alpha = error
 
-try:
-    from ..Methods.Slot.HoleM51.comp_mass_magnets import comp_mass_magnets
-except ImportError as error:
-    comp_mass_magnets = error
-
 try:
     from ..Methods.Slot.HoleM51.comp_radius import comp_radius
 except ImportError as error:
     comp_radius = error
 
-try:
-    from ..Methods.Slot.HoleM51.comp_surface_magnets import comp_surface_magnets
-except ImportError as error:
-    comp_surface_magnets = error
-
-try:
-    from ..Methods.Slot.HoleM51.comp_volume_magnets import comp_volume_magnets
-except ImportError as error:
-    comp_volume_magnets = error
-
 try:
     from ..Methods.Slot.HoleM51.comp_width import comp_width
 except ImportError as error:
     comp_width = error
 
 try:
-    from ..Methods.Slot.HoleM51.get_height_magnet import get_height_magnet
+    from ..Methods.Slot.HoleM51.has_magnet import has_magnet
 except ImportError as error:
-    get_height_magnet = error
+    has_magnet = error
 
 try:
     from ..Methods.Slot.HoleM51.remove_magnet import remove_magnet
@@ -64,9 +52,9 @@ except ImportError as error:
     remove_magnet = error
 
 try:
-    from ..Methods.Slot.HoleM51.has_magnet import has_magnet
+    from ..Methods.Slot.HoleM51.comp_surface_magnet_id import comp_surface_magnet_id
 except ImportError as error:
-    has_magnet = error
+    comp_surface_magnet_id = error
 
 
 from ._check import InitUnKnowClassError
@@ -110,18 +98,6 @@ class HoleM51(HoleMag):
         )
     else:
         comp_alpha = comp_alpha
-    # cf Methods.Slot.HoleM51.comp_mass_magnets
-    if isinstance(comp_mass_magnets, ImportError):
-        comp_mass_magnets = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use HoleM51 method comp_mass_magnets: "
-                    + str(comp_mass_magnets)
-                )
-            )
-        )
-    else:
-        comp_mass_magnets = comp_mass_magnets
     # cf Methods.Slot.HoleM51.comp_radius
     if isinstance(comp_radius, ImportError):
         comp_radius = property(
@@ -131,30 +107,6 @@ class HoleM51(HoleMag):
         )
     else:
         comp_radius = comp_radius
-    # cf Methods.Slot.HoleM51.comp_surface_magnets
-    if isinstance(comp_surface_magnets, ImportError):
-        comp_surface_magnets = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use HoleM51 method comp_surface_magnets: "
-                    + str(comp_surface_magnets)
-                )
-            )
-        )
-    else:
-        comp_surface_magnets = comp_surface_magnets
-    # cf Methods.Slot.HoleM51.comp_volume_magnets
-    if isinstance(comp_volume_magnets, ImportError):
-        comp_volume_magnets = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use HoleM51 method comp_volume_magnets: "
-                    + str(comp_volume_magnets)
-                )
-            )
-        )
-    else:
-        comp_volume_magnets = comp_volume_magnets
     # cf Methods.Slot.HoleM51.comp_width
     if isinstance(comp_width, ImportError):
         comp_width = property(
@@ -164,18 +116,15 @@ class HoleM51(HoleMag):
         )
     else:
         comp_width = comp_width
-    # cf Methods.Slot.HoleM51.get_height_magnet
-    if isinstance(get_height_magnet, ImportError):
-        get_height_magnet = property(
+    # cf Methods.Slot.HoleM51.has_magnet
+    if isinstance(has_magnet, ImportError):
+        has_magnet = property(
             fget=lambda x: raise_(
-                ImportError(
-                    "Can't use HoleM51 method get_height_magnet: "
-                    + str(get_height_magnet)
-                )
+                ImportError("Can't use HoleM51 method has_magnet: " + str(has_magnet))
             )
         )
     else:
-        get_height_magnet = get_height_magnet
+        has_magnet = has_magnet
     # cf Methods.Slot.HoleM51.remove_magnet
     if isinstance(remove_magnet, ImportError):
         remove_magnet = property(
@@ -187,24 +136,21 @@ class HoleM51(HoleMag):
         )
     else:
         remove_magnet = remove_magnet
-    # cf Methods.Slot.HoleM51.has_magnet
-    if isinstance(has_magnet, ImportError):
-        has_magnet = property(
+    # cf Methods.Slot.HoleM51.comp_surface_magnet_id
+    if isinstance(comp_surface_magnet_id, ImportError):
+        comp_surface_magnet_id = property(
             fget=lambda x: raise_(
-                ImportError("Can't use HoleM51 method has_magnet: " + str(has_magnet))
+                ImportError(
+                    "Can't use HoleM51 method comp_surface_magnet_id: "
+                    + str(comp_surface_magnet_id)
+                )
             )
         )
     else:
-        has_magnet = has_magnet
-    # save method is available in all object
+        comp_surface_magnet_id = comp_surface_magnet_id
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -231,46 +177,16 @@ class HoleM51(HoleMag):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if magnet_0 == -1:
-            magnet_0 = Magnet()
-        if magnet_1 == -1:
-            magnet_1 = Magnet()
-        if magnet_2 == -1:
-            magnet_2 = Magnet()
-        if mat_void == -1:
-            mat_void = Material()
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            H0 = obj.H0
-            H1 = obj.H1
-            H2 = obj.H2
-            W0 = obj.W0
-            W1 = obj.W1
-            W2 = obj.W2
-            W3 = obj.W3
-            W4 = obj.W4
-            W5 = obj.W5
-            W6 = obj.W6
-            W7 = obj.W7
-            magnet_0 = obj.magnet_0
-            magnet_1 = obj.magnet_1
-            magnet_2 = obj.magnet_2
-            Zh = obj.Zh
-            mat_void = obj.mat_void
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -306,7 +222,7 @@ class HoleM51(HoleMag):
                 Zh = init_dict["Zh"]
             if "mat_void" in list(init_dict.keys()):
                 mat_void = init_dict["mat_void"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         self.H0 = H0
         self.H1 = H1
         self.H2 = H2
@@ -318,142 +234,16 @@ class HoleM51(HoleMag):
         self.W5 = W5
         self.W6 = W6
         self.W7 = W7
-        # magnet_0 can be None, a Magnet object or a dict
-        if isinstance(magnet_0, dict):
-            # Check that the type is correct (including daughter)
-            class_name = magnet_0.get("__class__")
-            if class_name not in [
-                "Magnet",
-                "MagnetFlat",
-                "MagnetPolar",
-                "MagnetType10",
-                "MagnetType11",
-                "MagnetType12",
-                "MagnetType13",
-                "MagnetType14",
-            ]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for magnet_0"
-                )
-            # Dynamic import to call the correct constructor
-            module = __import__("pyleecan.Classes." + class_name, fromlist=[class_name])
-            class_obj = getattr(module, class_name)
-            self.magnet_0 = class_obj(init_dict=magnet_0)
-        elif isinstance(magnet_0, str):
-            from ..Functions.load import load
-
-            magnet_0 = load(magnet_0)
-            # Check that the type is correct (including daughter)
-            class_name = magnet_0.__class__.__name__
-            if class_name not in [
-                "Magnet",
-                "MagnetFlat",
-                "MagnetPolar",
-                "MagnetType10",
-                "MagnetType11",
-                "MagnetType12",
-                "MagnetType13",
-                "MagnetType14",
-            ]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for magnet_0"
-                )
-            self.magnet_0 = magnet_0
-        else:
-            self.magnet_0 = magnet_0
-        # magnet_1 can be None, a Magnet object or a dict
-        if isinstance(magnet_1, dict):
-            # Check that the type is correct (including daughter)
-            class_name = magnet_1.get("__class__")
-            if class_name not in [
-                "Magnet",
-                "MagnetFlat",
-                "MagnetPolar",
-                "MagnetType10",
-                "MagnetType11",
-                "MagnetType12",
-                "MagnetType13",
-                "MagnetType14",
-            ]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for magnet_1"
-                )
-            # Dynamic import to call the correct constructor
-            module = __import__("pyleecan.Classes." + class_name, fromlist=[class_name])
-            class_obj = getattr(module, class_name)
-            self.magnet_1 = class_obj(init_dict=magnet_1)
-        elif isinstance(magnet_1, str):
-            from ..Functions.load import load
-
-            magnet_1 = load(magnet_1)
-            # Check that the type is correct (including daughter)
-            class_name = magnet_1.__class__.__name__
-            if class_name not in [
-                "Magnet",
-                "MagnetFlat",
-                "MagnetPolar",
-                "MagnetType10",
-                "MagnetType11",
-                "MagnetType12",
-                "MagnetType13",
-                "MagnetType14",
-            ]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for magnet_1"
-                )
-            self.magnet_1 = magnet_1
-        else:
-            self.magnet_1 = magnet_1
-        # magnet_2 can be None, a Magnet object or a dict
-        if isinstance(magnet_2, dict):
-            # Check that the type is correct (including daughter)
-            class_name = magnet_2.get("__class__")
-            if class_name not in [
-                "Magnet",
-                "MagnetFlat",
-                "MagnetPolar",
-                "MagnetType10",
-                "MagnetType11",
-                "MagnetType12",
-                "MagnetType13",
-                "MagnetType14",
-            ]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for magnet_2"
-                )
-            # Dynamic import to call the correct constructor
-            module = __import__("pyleecan.Classes." + class_name, fromlist=[class_name])
-            class_obj = getattr(module, class_name)
-            self.magnet_2 = class_obj(init_dict=magnet_2)
-        elif isinstance(magnet_2, str):
-            from ..Functions.load import load
-
-            magnet_2 = load(magnet_2)
-            # Check that the type is correct (including daughter)
-            class_name = magnet_2.__class__.__name__
-            if class_name not in [
-                "Magnet",
-                "MagnetFlat",
-                "MagnetPolar",
-                "MagnetType10",
-                "MagnetType11",
-                "MagnetType12",
-                "MagnetType13",
-                "MagnetType14",
-            ]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for magnet_2"
-                )
-            self.magnet_2 = magnet_2
-        else:
-            self.magnet_2 = magnet_2
+        self.magnet_0 = magnet_0
+        self.magnet_1 = magnet_1
+        self.magnet_2 = magnet_2
         # Call HoleMag init
         super(HoleM51, self).__init__(Zh=Zh, mat_void=mat_void)
         # The class is frozen (in HoleMag init), for now it's impossible to
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         HoleM51_str = ""
         # Get the properties inherited from HoleMag
@@ -526,8 +316,7 @@ class HoleM51(HoleMag):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from HoleMag
         HoleM51_dict = super(HoleM51, self).as_dict()
@@ -554,7 +343,7 @@ class HoleM51(HoleMag):
             HoleM51_dict["magnet_2"] = None
         else:
             HoleM51_dict["magnet_2"] = self.magnet_2.as_dict()
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         HoleM51_dict["__class__"] = "HoleM51"
         return HoleM51_dict
@@ -797,6 +586,15 @@ class HoleM51(HoleMag):
 
     def _set_magnet_0(self, value):
         """setter of magnet_0"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "pyleecan.Classes", value.get("__class__"), "magnet_0"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = Magnet()
         check_var("magnet_0", value, "Magnet")
         self._magnet_0 = value
 
@@ -818,6 +616,15 @@ class HoleM51(HoleMag):
 
     def _set_magnet_1(self, value):
         """setter of magnet_1"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "pyleecan.Classes", value.get("__class__"), "magnet_1"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = Magnet()
         check_var("magnet_1", value, "Magnet")
         self._magnet_1 = value
 
@@ -839,6 +646,15 @@ class HoleM51(HoleMag):
 
     def _set_magnet_2(self, value):
         """setter of magnet_2"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "pyleecan.Classes", value.get("__class__"), "magnet_2"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = Magnet()
         check_var("magnet_2", value, "Magnet")
         self._magnet_2 = value
 
