@@ -9,6 +9,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from ._frozen import FrozenClass
 
 from ._check import InitUnKnowClassError
@@ -19,52 +22,42 @@ class Mesh(FrozenClass):
 
     VERSION = 1
 
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
-    def __init__(self, label=None, init_dict=None, init_str=None):
+    def __init__(self, label=None, dimension=2, init_dict=None, init_str=None):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            label = obj.label
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
             if "label" in list(init_dict.keys()):
                 label = init_dict["label"]
-        # Initialisation by argument
+            if "dimension" in list(init_dict.keys()):
+                dimension = init_dict["dimension"]
+        # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.label = label
+        self.dimension = dimension
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         Mesh_str = ""
         if self.parent is None:
@@ -72,6 +65,7 @@ class Mesh(FrozenClass):
         else:
             Mesh_str += "parent = " + str(type(self.parent)) + " object" + linesep
         Mesh_str += 'label = "' + str(self.label) + '"' + linesep
+        Mesh_str += "dimension = " + str(self.dimension) + linesep
         return Mesh_str
 
     def __eq__(self, other):
@@ -81,15 +75,17 @@ class Mesh(FrozenClass):
             return False
         if other.label != self.label:
             return False
+        if other.dimension != self.dimension:
+            return False
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         Mesh_dict = dict()
         Mesh_dict["label"] = self.label
-        # The class name is added to the dict fordeserialisation purpose
+        Mesh_dict["dimension"] = self.dimension
+        # The class name is added to the dict for deserialisation purpose
         Mesh_dict["__class__"] = "Mesh"
         return Mesh_dict
 
@@ -97,6 +93,7 @@ class Mesh(FrozenClass):
         """Set all the properties to None (except pyleecan object)"""
 
         self.label = None
+        self.dimension = None
 
     def _get_label(self):
         """getter of label"""
@@ -115,3 +112,23 @@ class Mesh(FrozenClass):
         :Type: str
         """,
     )
+
+    def _get_dimension(self):
+        """getter of dimension"""
+        return self._dimension
+
+    def _set_dimension(self, value):
+        """setter of dimension"""
+        check_var("dimension", value, "int", Vmin=1, Vmax=3)
+        self._dimension = value
+
+    dimension = property(
+        fget=_get_dimension,
+        fset=_set_dimension,
+        doc=u"""Dimension of the physical problem
+
+        :Type: int
+        :min: 1
+        :max: 3
+        """,
+    )
