@@ -9,6 +9,9 @@ from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -30,13 +33,6 @@ except ImportError as error:
 
 
 from numpy import array, array_equal
-from cloudpickle import dumps, loads
-from ._check import CheckTypeError
-
-try:
-    from SciDataTool.Classes.DataND import DataND
-except ImportError:
-    DataND = ImportError
 from ._check import InitUnKnowClassError
 
 
@@ -73,15 +69,9 @@ class OutElec(FrozenClass):
         )
     else:
         get_Us = get_Us
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -93,7 +83,6 @@ class OutElec(FrozenClass):
         Ir=None,
         angle_rotor=None,
         N0=None,
-        rot_dir=-1,
         angle_rotor_initial=0,
         logger_name="Pyleecan.OutElec",
         mmf_unit=None,
@@ -111,41 +100,16 @@ class OutElec(FrozenClass):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            time = obj.time
-            angle = obj.angle
-            Is = obj.Is
-            Ir = obj.Ir
-            angle_rotor = obj.angle_rotor
-            N0 = obj.N0
-            rot_dir = obj.rot_dir
-            angle_rotor_initial = obj.angle_rotor_initial
-            logger_name = obj.logger_name
-            mmf_unit = obj.mmf_unit
-            Tem_av_ref = obj.Tem_av_ref
-            Id_ref = obj.Id_ref
-            Iq_ref = obj.Iq_ref
-            felec = obj.felec
-            Ud_ref = obj.Ud_ref
-            Uq_ref = obj.Uq_ref
-            Pj_losses = obj.Pj_losses
-            Pem_av_ref = obj.Pem_av_ref
-            Us = obj.Us
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -161,8 +125,6 @@ class OutElec(FrozenClass):
                 angle_rotor = init_dict["angle_rotor"]
             if "N0" in list(init_dict.keys()):
                 N0 = init_dict["N0"]
-            if "rot_dir" in list(init_dict.keys()):
-                rot_dir = init_dict["rot_dir"]
             if "angle_rotor_initial" in list(init_dict.keys()):
                 angle_rotor_initial = init_dict["angle_rotor_initial"]
             if "logger_name" in list(init_dict.keys()):
@@ -187,21 +149,14 @@ class OutElec(FrozenClass):
                 Pem_av_ref = init_dict["Pem_av_ref"]
             if "Us" in list(init_dict.keys()):
                 Us = init_dict["Us"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         self.parent = None
-        # time can be None, a ndarray or a list
-        set_array(self, "time", time)
-        # angle can be None, a ndarray or a list
-        set_array(self, "angle", angle)
-        # Check if the type DataND has been imported with success
-        if isinstance(DataND, ImportError):
-            raise ImportError("Unknown type DataND please install SciDataTool")
+        self.time = time
+        self.angle = angle
         self.Is = Is
         self.Ir = Ir
-        # angle_rotor can be None, a ndarray or a list
-        set_array(self, "angle_rotor", angle_rotor)
+        self.angle_rotor = angle_rotor
         self.N0 = N0
-        self.rot_dir = rot_dir
         self.angle_rotor_initial = angle_rotor_initial
         self.logger_name = logger_name
         self.mmf_unit = mmf_unit
@@ -219,27 +174,15 @@ class OutElec(FrozenClass):
         self._freeze()
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         OutElec_str = ""
         if self.parent is None:
             OutElec_str += "parent = None " + linesep
         else:
             OutElec_str += "parent = " + str(type(self.parent)) + " object" + linesep
-        OutElec_str += (
-            "time = "
-            + linesep
-            + str(self.time).replace(linesep, linesep + "\t")
-            + linesep
-            + linesep
-        )
-        OutElec_str += (
-            "angle = "
-            + linesep
-            + str(self.angle).replace(linesep, linesep + "\t")
-            + linesep
-            + linesep
-        )
+        OutElec_str += "time = " + str(self.time) + linesep + linesep
+        OutElec_str += "angle = " + str(self.angle) + linesep + linesep
         OutElec_str += "Is = " + str(self.Is) + linesep + linesep
         OutElec_str += "Ir = " + str(self.Ir) + linesep + linesep
         OutElec_str += (
@@ -250,7 +193,6 @@ class OutElec(FrozenClass):
             + linesep
         )
         OutElec_str += "N0 = " + str(self.N0) + linesep
-        OutElec_str += "rot_dir = " + str(self.rot_dir) + linesep
         OutElec_str += (
             "angle_rotor_initial = " + str(self.angle_rotor_initial) + linesep
         )
@@ -272,9 +214,9 @@ class OutElec(FrozenClass):
 
         if type(other) != type(self):
             return False
-        if not array_equal(other.time, self.time):
+        if other.time != self.time:
             return False
-        if not array_equal(other.angle, self.angle):
+        if other.angle != self.angle:
             return False
         if other.Is != self.Is:
             return False
@@ -284,8 +226,6 @@ class OutElec(FrozenClass):
             return False
         if other.N0 != self.N0:
             return False
-        if other.rot_dir != self.rot_dir:
-            return False
         if other.angle_rotor_initial != self.angle_rotor_initial:
             return False
         if other.logger_name != self.logger_name:
@@ -313,50 +253,36 @@ class OutElec(FrozenClass):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         OutElec_dict = dict()
         if self.time is None:
             OutElec_dict["time"] = None
         else:
-            OutElec_dict["time"] = self.time.tolist()
+            OutElec_dict["time"] = self.time.as_dict()
         if self.angle is None:
             OutElec_dict["angle"] = None
         else:
-            OutElec_dict["angle"] = self.angle.tolist()
+            OutElec_dict["angle"] = self.angle.as_dict()
         if self.Is is None:
             OutElec_dict["Is"] = None
-        else:  # Store serialized data (using cloudpickle) and str to read it in json save files
-            OutElec_dict["Is"] = {
-                "__class__": str(type(self._Is)),
-                "__repr__": str(self._Is.__repr__()),
-                "serialized": dumps(self._Is).decode("ISO-8859-2"),
-            }
+        else:
+            OutElec_dict["Is"] = self.Is.as_dict()
         if self.Ir is None:
             OutElec_dict["Ir"] = None
-        else:  # Store serialized data (using cloudpickle) and str to read it in json save files
-            OutElec_dict["Ir"] = {
-                "__class__": str(type(self._Ir)),
-                "__repr__": str(self._Ir.__repr__()),
-                "serialized": dumps(self._Ir).decode("ISO-8859-2"),
-            }
+        else:
+            OutElec_dict["Ir"] = self.Ir.as_dict()
         if self.angle_rotor is None:
             OutElec_dict["angle_rotor"] = None
         else:
             OutElec_dict["angle_rotor"] = self.angle_rotor.tolist()
         OutElec_dict["N0"] = self.N0
-        OutElec_dict["rot_dir"] = self.rot_dir
         OutElec_dict["angle_rotor_initial"] = self.angle_rotor_initial
         OutElec_dict["logger_name"] = self.logger_name
         if self.mmf_unit is None:
             OutElec_dict["mmf_unit"] = None
-        else:  # Store serialized data (using cloudpickle) and str to read it in json save files
-            OutElec_dict["mmf_unit"] = {
-                "__class__": str(type(self._mmf_unit)),
-                "__repr__": str(self._mmf_unit.__repr__()),
-                "serialized": dumps(self._mmf_unit).decode("ISO-8859-2"),
-            }
+        else:
+            OutElec_dict["mmf_unit"] = self.mmf_unit.as_dict()
         OutElec_dict["Tem_av_ref"] = self.Tem_av_ref
         OutElec_dict["Id_ref"] = self.Id_ref
         OutElec_dict["Iq_ref"] = self.Iq_ref
@@ -367,13 +293,9 @@ class OutElec(FrozenClass):
         OutElec_dict["Pem_av_ref"] = self.Pem_av_ref
         if self.Us is None:
             OutElec_dict["Us"] = None
-        else:  # Store serialized data (using cloudpickle) and str to read it in json save files
-            OutElec_dict["Us"] = {
-                "__class__": str(type(self._Us)),
-                "__repr__": str(self._Us.__repr__()),
-                "serialized": dumps(self._Us).decode("ISO-8859-2"),
-            }
-        # The class name is added to the dict fordeserialisation purpose
+        else:
+            OutElec_dict["Us"] = self.Us.as_dict()
+        # The class name is added to the dict for deserialisation purpose
         OutElec_dict["__class__"] = "OutElec"
         return OutElec_dict
 
@@ -386,7 +308,6 @@ class OutElec(FrozenClass):
         self.Ir = None
         self.angle_rotor = None
         self.N0 = None
-        self.rot_dir = None
         self.angle_rotor_initial = None
         self.logger_name = None
         self.mmf_unit = None
@@ -406,14 +327,16 @@ class OutElec(FrozenClass):
 
     def _set_time(self, value):
         """setter of time"""
-        if value is None:
-            value = array([])
-        elif type(value) is list:
-            try:
-                value = array(value)
-            except:
-                pass
-        check_var("time", value, "ndarray")
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "time"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = Data()
+        check_var("time", value, "Data")
         self._time = value
 
     time = property(
@@ -421,7 +344,7 @@ class OutElec(FrozenClass):
         fset=_set_time,
         doc=u"""Electrical time vector (no symmetry)
 
-        :Type: ndarray
+        :Type: SciDataTool.Classes.DataND.Data
         """,
     )
 
@@ -431,14 +354,16 @@ class OutElec(FrozenClass):
 
     def _set_angle(self, value):
         """setter of angle"""
-        if value is None:
-            value = array([])
-        elif type(value) is list:
-            try:
-                value = array(value)
-            except:
-                pass
-        check_var("angle", value, "ndarray")
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "angle"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = Data()
+        check_var("angle", value, "Data")
         self._angle = value
 
     angle = property(
@@ -446,7 +371,7 @@ class OutElec(FrozenClass):
         fset=_set_angle,
         doc=u"""Electrical position vector (no symmetry)
 
-        :Type: ndarray
+        :Type: SciDataTool.Classes.DataND.Data
         """,
     )
 
@@ -456,17 +381,17 @@ class OutElec(FrozenClass):
 
     def _set_Is(self, value):
         """setter of Is"""
-        try:  # Check the type
-            check_var("Is", value, "dict")
-        except CheckTypeError:
-            check_var("Is", value, "SciDataTool.Classes.DataND.DataND")
-            # property can be set from a list to handle loads
-        if (
-            type(value) == dict
-        ):  # Load type from saved dict {"type":type(value),"str": str(value),"serialized": serialized(value)]
-            self._Is = loads(value["serialized"].encode("ISO-8859-2"))
-        else:
-            self._Is = value
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "Is"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataND()
+        check_var("Is", value, "DataND")
+        self._Is = value
 
     Is = property(
         fget=_get_Is,
@@ -483,17 +408,17 @@ class OutElec(FrozenClass):
 
     def _set_Ir(self, value):
         """setter of Ir"""
-        try:  # Check the type
-            check_var("Ir", value, "dict")
-        except CheckTypeError:
-            check_var("Ir", value, "SciDataTool.Classes.DataND.DataND")
-            # property can be set from a list to handle loads
-        if (
-            type(value) == dict
-        ):  # Load type from saved dict {"type":type(value),"str": str(value),"serialized": serialized(value)]
-            self._Ir = loads(value["serialized"].encode("ISO-8859-2"))
-        else:
-            self._Ir = value
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "Ir"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataND()
+        check_var("Ir", value, "DataND")
+        self._Ir = value
 
     Ir = property(
         fget=_get_Ir,
@@ -510,7 +435,7 @@ class OutElec(FrozenClass):
 
     def _set_angle_rotor(self, value):
         """setter of angle_rotor"""
-        if value is None:
+        if type(value) is int and value == -1:
             value = array([])
         elif type(value) is list:
             try:
@@ -547,26 +472,6 @@ class OutElec(FrozenClass):
         """,
     )
 
-    def _get_rot_dir(self):
-        """getter of rot_dir"""
-        return self._rot_dir
-
-    def _set_rot_dir(self, value):
-        """setter of rot_dir"""
-        check_var("rot_dir", value, "float", Vmin=-1, Vmax=1)
-        self._rot_dir = value
-
-    rot_dir = property(
-        fget=_get_rot_dir,
-        fset=_set_rot_dir,
-        doc=u"""Rotation direction of the rotor 1 trigo, -1 clockwise
-
-        :Type: float
-        :min: -1
-        :max: 1
-        """,
-    )
-
     def _get_angle_rotor_initial(self):
         """getter of angle_rotor_initial"""
         return self._angle_rotor_initial
@@ -609,17 +514,17 @@ class OutElec(FrozenClass):
 
     def _set_mmf_unit(self, value):
         """setter of mmf_unit"""
-        try:  # Check the type
-            check_var("mmf_unit", value, "dict")
-        except CheckTypeError:
-            check_var("mmf_unit", value, "SciDataTool.Classes.DataND.DataND")
-            # property can be set from a list to handle loads
-        if (
-            type(value) == dict
-        ):  # Load type from saved dict {"type":type(value),"str": str(value),"serialized": serialized(value)]
-            self._mmf_unit = loads(value["serialized"].encode("ISO-8859-2"))
-        else:
-            self._mmf_unit = value
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "mmf_unit"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataND()
+        check_var("mmf_unit", value, "DataND")
+        self._mmf_unit = value
 
     mmf_unit = property(
         fget=_get_mmf_unit,
@@ -780,17 +685,17 @@ class OutElec(FrozenClass):
 
     def _set_Us(self, value):
         """setter of Us"""
-        try:  # Check the type
-            check_var("Us", value, "dict")
-        except CheckTypeError:
-            check_var("Us", value, "SciDataTool.Classes.DataND.DataND")
-            # property can be set from a list to handle loads
-        if (
-            type(value) == dict
-        ):  # Load type from saved dict {"type":type(value),"str": str(value),"serialized": serialized(value)]
-            self._Us = loads(value["serialized"].encode("ISO-8859-2"))
-        else:
-            self._Us = value
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "Us"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataND()
+        check_var("Us", value, "DataND")
+        self._Us = value
 
     Us = property(
         fget=_get_Us,
