@@ -9,20 +9,12 @@ from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from ._frozen import FrozenClass
 
 from numpy import array, array_equal
-from cloudpickle import dumps, loads
-from ._check import CheckTypeError
-
-try:
-    from SciDataTool.Classes.VectorField import VectorField
-except ImportError:
-    VectorField = ImportError
-try:
-    from SciDataTool.Classes.DataND import DataND
-except ImportError:
-    DataND = ImportError
 from ._check import InitUnKnowClassError
 from .MeshSolution import MeshSolution
 
@@ -32,15 +24,9 @@ class OutMag(FrozenClass):
 
     VERSION = 1
 
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -48,8 +34,6 @@ class OutMag(FrozenClass):
         self,
         time=None,
         angle=None,
-        Nt_tot=None,
-        Na_tot=None,
         B=None,
         Tem=None,
         Tem_av=None,
@@ -65,38 +49,16 @@ class OutMag(FrozenClass):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if meshsolution == -1:
-            meshsolution = MeshSolution()
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            time = obj.time
-            angle = obj.angle
-            Nt_tot = obj.Nt_tot
-            Na_tot = obj.Na_tot
-            B = obj.B
-            Tem = obj.Tem
-            Tem_av = obj.Tem_av
-            Tem_rip_norm = obj.Tem_rip_norm
-            Tem_rip_pp = obj.Tem_rip_pp
-            Phi_wind_stator = obj.Phi_wind_stator
-            emf = obj.emf
-            meshsolution = obj.meshsolution
-            FEMM_dict = obj.FEMM_dict
-            logger_name = obj.logger_name
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -104,10 +66,6 @@ class OutMag(FrozenClass):
                 time = init_dict["time"]
             if "angle" in list(init_dict.keys()):
                 angle = init_dict["angle"]
-            if "Nt_tot" in list(init_dict.keys()):
-                Nt_tot = init_dict["Nt_tot"]
-            if "Na_tot" in list(init_dict.keys()):
-                Na_tot = init_dict["Na_tot"]
             if "B" in list(init_dict.keys()):
                 B = init_dict["B"]
             if "Tem" in list(init_dict.keys()):
@@ -128,38 +86,18 @@ class OutMag(FrozenClass):
                 FEMM_dict = init_dict["FEMM_dict"]
             if "logger_name" in list(init_dict.keys()):
                 logger_name = init_dict["logger_name"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         self.parent = None
-        # time can be None, a ndarray or a list
-        set_array(self, "time", time)
-        # angle can be None, a ndarray or a list
-        set_array(self, "angle", angle)
-        self.Nt_tot = Nt_tot
-        self.Na_tot = Na_tot
-        # Check if the type VectorField has been imported with success
-        if isinstance(VectorField, ImportError):
-            raise ImportError("Unknown type VectorField please install SciDataTool")
+        self.time = time
+        self.angle = angle
         self.B = B
-        # Check if the type DataND has been imported with success
-        if isinstance(DataND, ImportError):
-            raise ImportError("Unknown type DataND please install SciDataTool")
         self.Tem = Tem
         self.Tem_av = Tem_av
         self.Tem_rip_norm = Tem_rip_norm
         self.Tem_rip_pp = Tem_rip_pp
-        # Phi_wind_stator can be None, a ndarray or a list
-        set_array(self, "Phi_wind_stator", Phi_wind_stator)
-        # emf can be None, a ndarray or a list
-        set_array(self, "emf", emf)
-        # meshsolution can be None, a MeshSolution object or a dict
-        if isinstance(meshsolution, dict):
-            self.meshsolution = MeshSolution(init_dict=meshsolution)
-        elif isinstance(meshsolution, str):
-            from ..Functions.load import load
-
-            self.meshsolution = load(meshsolution)
-        else:
-            self.meshsolution = meshsolution
+        self.Phi_wind_stator = Phi_wind_stator
+        self.emf = emf
+        self.meshsolution = meshsolution
         self.FEMM_dict = FEMM_dict
         self.logger_name = logger_name
 
@@ -167,40 +105,22 @@ class OutMag(FrozenClass):
         self._freeze()
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         OutMag_str = ""
         if self.parent is None:
             OutMag_str += "parent = None " + linesep
         else:
             OutMag_str += "parent = " + str(type(self.parent)) + " object" + linesep
-        OutMag_str += (
-            "time = "
-            + linesep
-            + str(self.time).replace(linesep, linesep + "\t")
-            + linesep
-            + linesep
-        )
-        OutMag_str += (
-            "angle = "
-            + linesep
-            + str(self.angle).replace(linesep, linesep + "\t")
-            + linesep
-            + linesep
-        )
-        OutMag_str += "Nt_tot = " + str(self.Nt_tot) + linesep
-        OutMag_str += "Na_tot = " + str(self.Na_tot) + linesep
+        OutMag_str += "time = " + str(self.time) + linesep + linesep
+        OutMag_str += "angle = " + str(self.angle) + linesep + linesep
         OutMag_str += "B = " + str(self.B) + linesep + linesep
         OutMag_str += "Tem = " + str(self.Tem) + linesep + linesep
         OutMag_str += "Tem_av = " + str(self.Tem_av) + linesep
         OutMag_str += "Tem_rip_norm = " + str(self.Tem_rip_norm) + linesep
         OutMag_str += "Tem_rip_pp = " + str(self.Tem_rip_pp) + linesep
         OutMag_str += (
-            "Phi_wind_stator = "
-            + linesep
-            + str(self.Phi_wind_stator).replace(linesep, linesep + "\t")
-            + linesep
-            + linesep
+            "Phi_wind_stator = " + str(self.Phi_wind_stator) + linesep + linesep
         )
         OutMag_str += (
             "emf = "
@@ -227,13 +147,9 @@ class OutMag(FrozenClass):
 
         if type(other) != type(self):
             return False
-        if not array_equal(other.time, self.time):
+        if other.time != self.time:
             return False
-        if not array_equal(other.angle, self.angle):
-            return False
-        if other.Nt_tot != self.Nt_tot:
-            return False
-        if other.Na_tot != self.Na_tot:
+        if other.angle != self.angle:
             return False
         if other.B != self.B:
             return False
@@ -245,7 +161,7 @@ class OutMag(FrozenClass):
             return False
         if other.Tem_rip_pp != self.Tem_rip_pp:
             return False
-        if not array_equal(other.Phi_wind_stator, self.Phi_wind_stator):
+        if other.Phi_wind_stator != self.Phi_wind_stator:
             return False
         if not array_equal(other.emf, self.emf):
             return False
@@ -258,43 +174,32 @@ class OutMag(FrozenClass):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         OutMag_dict = dict()
         if self.time is None:
             OutMag_dict["time"] = None
         else:
-            OutMag_dict["time"] = self.time.tolist()
+            OutMag_dict["time"] = self.time.as_dict()
         if self.angle is None:
             OutMag_dict["angle"] = None
         else:
-            OutMag_dict["angle"] = self.angle.tolist()
-        OutMag_dict["Nt_tot"] = self.Nt_tot
-        OutMag_dict["Na_tot"] = self.Na_tot
+            OutMag_dict["angle"] = self.angle.as_dict()
         if self.B is None:
             OutMag_dict["B"] = None
-        else:  # Store serialized data (using cloudpickle) and str to read it in json save files
-            OutMag_dict["B"] = {
-                "__class__": str(type(self._B)),
-                "__repr__": str(self._B.__repr__()),
-                "serialized": dumps(self._B).decode("ISO-8859-2"),
-            }
+        else:
+            OutMag_dict["B"] = self.B.as_dict()
         if self.Tem is None:
             OutMag_dict["Tem"] = None
-        else:  # Store serialized data (using cloudpickle) and str to read it in json save files
-            OutMag_dict["Tem"] = {
-                "__class__": str(type(self._Tem)),
-                "__repr__": str(self._Tem.__repr__()),
-                "serialized": dumps(self._Tem).decode("ISO-8859-2"),
-            }
+        else:
+            OutMag_dict["Tem"] = self.Tem.as_dict()
         OutMag_dict["Tem_av"] = self.Tem_av
         OutMag_dict["Tem_rip_norm"] = self.Tem_rip_norm
         OutMag_dict["Tem_rip_pp"] = self.Tem_rip_pp
         if self.Phi_wind_stator is None:
             OutMag_dict["Phi_wind_stator"] = None
         else:
-            OutMag_dict["Phi_wind_stator"] = self.Phi_wind_stator.tolist()
+            OutMag_dict["Phi_wind_stator"] = self.Phi_wind_stator.as_dict()
         if self.emf is None:
             OutMag_dict["emf"] = None
         else:
@@ -303,9 +208,11 @@ class OutMag(FrozenClass):
             OutMag_dict["meshsolution"] = None
         else:
             OutMag_dict["meshsolution"] = self.meshsolution.as_dict()
-        OutMag_dict["FEMM_dict"] = self.FEMM_dict
+        OutMag_dict["FEMM_dict"] = (
+            self.FEMM_dict.copy() if self.FEMM_dict is not None else None
+        )
         OutMag_dict["logger_name"] = self.logger_name
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         OutMag_dict["__class__"] = "OutMag"
         return OutMag_dict
 
@@ -314,8 +221,6 @@ class OutMag(FrozenClass):
 
         self.time = None
         self.angle = None
-        self.Nt_tot = None
-        self.Na_tot = None
         self.B = None
         self.Tem = None
         self.Tem_av = None
@@ -334,14 +239,16 @@ class OutMag(FrozenClass):
 
     def _set_time(self, value):
         """setter of time"""
-        if value is None:
-            value = array([])
-        elif type(value) is list:
-            try:
-                value = array(value)
-            except:
-                pass
-        check_var("time", value, "ndarray")
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "time"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = Data()
+        check_var("time", value, "Data")
         self._time = value
 
     time = property(
@@ -349,7 +256,7 @@ class OutMag(FrozenClass):
         fset=_set_time,
         doc=u"""Magnetic time vector (no symmetry)
 
-        :Type: ndarray
+        :Type: SciDataTool.Classes.DataND.Data
         """,
     )
 
@@ -359,14 +266,16 @@ class OutMag(FrozenClass):
 
     def _set_angle(self, value):
         """setter of angle"""
-        if value is None:
-            value = array([])
-        elif type(value) is list:
-            try:
-                value = array(value)
-            except:
-                pass
-        check_var("angle", value, "ndarray")
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "angle"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = Data()
+        check_var("angle", value, "Data")
         self._angle = value
 
     angle = property(
@@ -374,43 +283,7 @@ class OutMag(FrozenClass):
         fset=_set_angle,
         doc=u"""Magnetic position vector (no symmetry)
 
-        :Type: ndarray
-        """,
-    )
-
-    def _get_Nt_tot(self):
-        """getter of Nt_tot"""
-        return self._Nt_tot
-
-    def _set_Nt_tot(self, value):
-        """setter of Nt_tot"""
-        check_var("Nt_tot", value, "int")
-        self._Nt_tot = value
-
-    Nt_tot = property(
-        fget=_get_Nt_tot,
-        fset=_set_Nt_tot,
-        doc=u"""Length of the time vector
-
-        :Type: int
-        """,
-    )
-
-    def _get_Na_tot(self):
-        """getter of Na_tot"""
-        return self._Na_tot
-
-    def _set_Na_tot(self, value):
-        """setter of Na_tot"""
-        check_var("Na_tot", value, "int")
-        self._Na_tot = value
-
-    Na_tot = property(
-        fget=_get_Na_tot,
-        fset=_set_Na_tot,
-        doc=u"""Length of the angle vector
-
-        :Type: int
+        :Type: SciDataTool.Classes.DataND.Data
         """,
     )
 
@@ -420,17 +293,15 @@ class OutMag(FrozenClass):
 
     def _set_B(self, value):
         """setter of B"""
-        try:  # Check the type
-            check_var("B", value, "dict")
-        except CheckTypeError:
-            check_var("B", value, "SciDataTool.Classes.VectorField.VectorField")
-            # property can be set from a list to handle loads
-        if (
-            type(value) == dict
-        ):  # Load type from saved dict {"type":type(value),"str": str(value),"serialized": serialized(value)]
-            self._B = loads(value["serialized"].encode("ISO-8859-2"))
-        else:
-            self._B = value
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class("SciDataTool.Classes", value.get("__class__"), "B")
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = VectorField()
+        check_var("B", value, "VectorField")
+        self._B = value
 
     B = property(
         fget=_get_B,
@@ -447,17 +318,17 @@ class OutMag(FrozenClass):
 
     def _set_Tem(self, value):
         """setter of Tem"""
-        try:  # Check the type
-            check_var("Tem", value, "dict")
-        except CheckTypeError:
-            check_var("Tem", value, "SciDataTool.Classes.DataND.DataND")
-            # property can be set from a list to handle loads
-        if (
-            type(value) == dict
-        ):  # Load type from saved dict {"type":type(value),"str": str(value),"serialized": serialized(value)]
-            self._Tem = loads(value["serialized"].encode("ISO-8859-2"))
-        else:
-            self._Tem = value
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "Tem"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataND()
+        check_var("Tem", value, "DataND")
+        self._Tem = value
 
     Tem = property(
         fget=_get_Tem,
@@ -528,14 +399,16 @@ class OutMag(FrozenClass):
 
     def _set_Phi_wind_stator(self, value):
         """setter of Phi_wind_stator"""
-        if value is None:
-            value = array([])
-        elif type(value) is list:
-            try:
-                value = array(value)
-            except:
-                pass
-        check_var("Phi_wind_stator", value, "ndarray")
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "Phi_wind_stator"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataTime()
+        check_var("Phi_wind_stator", value, "DataTime")
         self._Phi_wind_stator = value
 
     Phi_wind_stator = property(
@@ -543,7 +416,7 @@ class OutMag(FrozenClass):
         fset=_set_Phi_wind_stator,
         doc=u"""Stator winding flux
 
-        :Type: ndarray
+        :Type: SciDataTool.Classes.DataTime.DataTime
         """,
     )
 
@@ -553,7 +426,7 @@ class OutMag(FrozenClass):
 
     def _set_emf(self, value):
         """setter of emf"""
-        if value is None:
+        if type(value) is int and value == -1:
             value = array([])
         elif type(value) is list:
             try:
@@ -578,6 +451,15 @@ class OutMag(FrozenClass):
 
     def _set_meshsolution(self, value):
         """setter of meshsolution"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "pyleecan.Classes", value.get("__class__"), "meshsolution"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = MeshSolution()
         check_var("meshsolution", value, "MeshSolution")
         self._meshsolution = value
 
@@ -599,6 +481,8 @@ class OutMag(FrozenClass):
 
     def _set_FEMM_dict(self, value):
         """setter of FEMM_dict"""
+        if type(value) is int and value == -1:
+            value = dict()
         check_var("FEMM_dict", value, "dict")
         self._FEMM_dict = value
 
