@@ -9,6 +9,9 @@ from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .Solution import Solution
 
 # Import all class method
@@ -23,11 +26,6 @@ try:
 except ImportError as error:
     get_axis = error
 
-try:
-    from ..Methods.Mesh.SolutionMat.set_field import set_field
-except ImportError as error:
-    set_field = error
-
 
 from numpy import array, array_equal
 from ._check import InitUnKnowClassError
@@ -57,24 +55,9 @@ class SolutionMat(Solution):
         )
     else:
         get_axis = get_axis
-    # cf Methods.Mesh.SolutionMat.set_field
-    if isinstance(set_field, ImportError):
-        set_field = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use SolutionMat method set_field: " + str(set_field))
-            )
-        )
-    else:
-        set_field = set_field
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -85,32 +68,22 @@ class SolutionMat(Solution):
         axis=None,
         type_cell="triangle",
         label=None,
+        dimension=2,
         init_dict=None,
         init_str=None,
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            field = obj.field
-            indice = obj.indice
-            axis = obj.axis
-            type_cell = obj.type_cell
-            label = obj.label
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -124,19 +97,21 @@ class SolutionMat(Solution):
                 type_cell = init_dict["type_cell"]
             if "label" in list(init_dict.keys()):
                 label = init_dict["label"]
-        # Initialisation by argument
-        # field can be None, a ndarray or a list
-        set_array(self, "field", field)
-        # indice can be None, a ndarray or a list
-        set_array(self, "indice", indice)
+            if "dimension" in list(init_dict.keys()):
+                dimension = init_dict["dimension"]
+        # Set the properties (value check and convertion are done in setter)
+        self.field = field
+        self.indice = indice
         self.axis = axis
         # Call Solution init
-        super(SolutionMat, self).__init__(type_cell=type_cell, label=label)
+        super(SolutionMat, self).__init__(
+            type_cell=type_cell, label=label, dimension=dimension
+        )
         # The class is frozen (in Solution init), for now it's impossible to
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         SolutionMat_str = ""
         # Get the properties inherited from Solution
@@ -176,8 +151,7 @@ class SolutionMat(Solution):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from Solution
         SolutionMat_dict = super(SolutionMat, self).as_dict()
@@ -189,8 +163,8 @@ class SolutionMat(Solution):
             SolutionMat_dict["indice"] = None
         else:
             SolutionMat_dict["indice"] = self.indice.tolist()
-        SolutionMat_dict["axis"] = self.axis
-        # The class name is added to the dict fordeserialisation purpose
+        SolutionMat_dict["axis"] = self.axis.copy() if self.axis is not None else None
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         SolutionMat_dict["__class__"] = "SolutionMat"
         return SolutionMat_dict
@@ -210,7 +184,7 @@ class SolutionMat(Solution):
 
     def _set_field(self, value):
         """setter of field"""
-        if value is None:
+        if type(value) is int and value == -1:
             value = array([])
         elif type(value) is list:
             try:
@@ -235,7 +209,7 @@ class SolutionMat(Solution):
 
     def _set_indice(self, value):
         """setter of indice"""
-        if value is None:
+        if type(value) is int and value == -1:
             value = array([])
         elif type(value) is list:
             try:
@@ -260,6 +234,8 @@ class SolutionMat(Solution):
 
     def _set_axis(self, value):
         """setter of axis"""
+        if type(value) is int and value == -1:
+            value = dict()
         check_var("axis", value, "dict")
         self._axis = value
 
