@@ -9,6 +9,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .Output import Output
 
 # Import all class method
@@ -125,6 +128,9 @@ except ImportError as error:
 
 
 from ._check import InitUnKnowClassError
+from .ParamExplorer import ParamExplorer
+from .Output import Output
+from .DataKeeper import DataKeeper
 from .Simulation import Simulation
 from .OutGeo import OutGeo
 from .OutElec import OutElec
@@ -350,23 +356,17 @@ class XOutput(Output):
         )
     else:
         get_pareto_index = get_pareto_index
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
     def __init__(
         self,
-        paramexplorer_list=[],
-        output_list=[],
-        xoutput_dict={},
+        paramexplorer_list=-1,
+        output_list=-1,
+        xoutput_dict=-1,
         nb_simu=0,
         simu=-1,
         path_res="",
@@ -382,49 +382,16 @@ class XOutput(Output):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if simu == -1:
-            simu = Simulation()
-        if geo == -1:
-            geo = OutGeo()
-        if elec == -1:
-            elec = OutElec()
-        if mag == -1:
-            mag = OutMag()
-        if struct == -1:
-            struct = OutStruct()
-        if post == -1:
-            post = OutPost()
-        if force == -1:
-            force = OutForce()
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            paramexplorer_list = obj.paramexplorer_list
-            output_list = obj.output_list
-            xoutput_dict = obj.xoutput_dict
-            nb_simu = obj.nb_simu
-            simu = obj.simu
-            path_res = obj.path_res
-            geo = obj.geo
-            elec = obj.elec
-            mag = obj.mag
-            struct = obj.struct
-            post = obj.post
-            logger_name = obj.logger_name
-            force = obj.force
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -454,12 +421,8 @@ class XOutput(Output):
                 logger_name = init_dict["logger_name"]
             if "force" in list(init_dict.keys()):
                 force = init_dict["force"]
-        # Initialisation by argument
-        if paramexplorer_list == -1:
-            paramexplorer_list = []
+        # Set the properties (value check and convertion are done in setter)
         self.paramexplorer_list = paramexplorer_list
-        if output_list == -1:
-            output_list = []
         self.output_list = output_list
         self.xoutput_dict = xoutput_dict
         self.nb_simu = nb_simu
@@ -479,24 +442,37 @@ class XOutput(Output):
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         XOutput_str = ""
         # Get the properties inherited from Output
         XOutput_str += super(XOutput, self).__str__()
-        XOutput_str += (
-            "paramexplorer_list = "
-            + linesep
-            + str(self.paramexplorer_list).replace(linesep, linesep + "\t")
-            + linesep
-        )
-        XOutput_str += (
-            "output_list = "
-            + linesep
-            + str(self.output_list).replace(linesep, linesep + "\t")
-            + linesep
-        )
-        XOutput_str += "xoutput_dict = " + str(self.xoutput_dict) + linesep
+        if len(self.paramexplorer_list) == 0:
+            XOutput_str += "paramexplorer_list = []" + linesep
+        for ii in range(len(self.paramexplorer_list)):
+            tmp = (
+                self.paramexplorer_list[ii].__str__().replace(linesep, linesep + "\t")
+                + linesep
+            )
+            XOutput_str += (
+                "paramexplorer_list[" + str(ii) + "] =" + tmp + linesep + linesep
+            )
+        if len(self.output_list) == 0:
+            XOutput_str += "output_list = []" + linesep
+        for ii in range(len(self.output_list)):
+            tmp = (
+                self.output_list[ii].__str__().replace(linesep, linesep + "\t")
+                + linesep
+            )
+            XOutput_str += "output_list[" + str(ii) + "] =" + tmp + linesep + linesep
+        if len(self.xoutput_dict) == 0:
+            XOutput_str += "xoutput_dict = dict()" + linesep
+        for key, obj in self.xoutput_dict.items():
+            tmp = (
+                self.xoutput_dict[key].__str__().replace(linesep, linesep + "\t")
+                + linesep
+            )
+            XOutput_str += "xoutput_dict[" + key + "] =" + tmp + linesep + linesep
         XOutput_str += "nb_simu = " + str(self.nb_simu) + linesep
         return XOutput_str
 
@@ -520,16 +496,30 @@ class XOutput(Output):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from Output
         XOutput_dict = super(XOutput, self).as_dict()
-        XOutput_dict["paramexplorer_list"] = self.paramexplorer_list
-        XOutput_dict["output_list"] = self.output_list
-        XOutput_dict["xoutput_dict"] = self.xoutput_dict
+        if self.paramexplorer_list is None:
+            XOutput_dict["paramexplorer_list"] = None
+        else:
+            XOutput_dict["paramexplorer_list"] = list()
+            for obj in self.paramexplorer_list:
+                XOutput_dict["paramexplorer_list"].append(obj.as_dict())
+        if self.output_list is None:
+            XOutput_dict["output_list"] = None
+        else:
+            XOutput_dict["output_list"] = list()
+            for obj in self.output_list:
+                XOutput_dict["output_list"].append(obj.as_dict())
+        if self.xoutput_dict is None:
+            XOutput_dict["xoutput_dict"] = None
+        else:
+            XOutput_dict["xoutput_dict"] = dict()
+            for key, obj in self.xoutput_dict.items():
+                XOutput_dict["xoutput_dict"][key] = obj.as_dict()
         XOutput_dict["nb_simu"] = self.nb_simu
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         XOutput_dict["__class__"] = "XOutput"
         return XOutput_dict
@@ -537,20 +527,36 @@ class XOutput(Output):
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        self.paramexplorer_list = None
-        self.output_list = None
-        self.xoutput_dict = None
+        for obj in self.paramexplorer_list:
+            obj._set_None()
+        for obj in self.output_list:
+            obj._set_None()
+        for key, obj in self.xoutput_dict.items():
+            obj._set_None()
         self.nb_simu = None
         # Set to None the properties inherited from Output
         super(XOutput, self)._set_None()
 
     def _get_paramexplorer_list(self):
         """getter of paramexplorer_list"""
+        if self._paramexplorer_list is not None:
+            for obj in self._paramexplorer_list:
+                if obj is not None:
+                    obj.parent = self
         return self._paramexplorer_list
 
     def _set_paramexplorer_list(self, value):
         """setter of paramexplorer_list"""
-        check_var("paramexplorer_list", value, "list")
+        if type(value) is list:
+            for ii, obj in enumerate(value):
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "pyleecan.Classes", obj.get("__class__"), "paramexplorer_list"
+                    )
+                    value[ii] = class_obj(init_dict=obj)
+        if value == -1:
+            value = list()
+        check_var("paramexplorer_list", value, "[ParamExplorer]")
         self._paramexplorer_list = value
 
     paramexplorer_list = property(
@@ -558,17 +564,30 @@ class XOutput(Output):
         fset=_set_paramexplorer_list,
         doc=u"""List containing ParamExplorer
 
-        :Type: list
+        :Type: [ParamExplorer]
         """,
     )
 
     def _get_output_list(self):
         """getter of output_list"""
+        if self._output_list is not None:
+            for obj in self._output_list:
+                if obj is not None:
+                    obj.parent = self
         return self._output_list
 
     def _set_output_list(self, value):
         """setter of output_list"""
-        check_var("output_list", value, "list")
+        if type(value) is list:
+            for ii, obj in enumerate(value):
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "pyleecan.Classes", obj.get("__class__"), "output_list"
+                    )
+                    value[ii] = class_obj(init_dict=obj)
+        if value == -1:
+            value = list()
+        check_var("output_list", value, "[Output]")
         self._output_list = value
 
     output_list = property(
@@ -576,17 +595,30 @@ class XOutput(Output):
         fset=_set_output_list,
         doc=u"""List containing Output for each simulation
 
-        :Type: list
+        :Type: [Output]
         """,
     )
 
     def _get_xoutput_dict(self):
         """getter of xoutput_dict"""
+        if self._xoutput_dict is not None:
+            for key, obj in self._xoutput_dict.items():
+                if obj is not None:
+                    obj.parent = self
         return self._xoutput_dict
 
     def _set_xoutput_dict(self, value):
         """setter of xoutput_dict"""
-        check_var("xoutput_dict", value, "dict")
+        if type(value) is dict:
+            for key, obj in value.items():
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "pyleecan.Classes", obj.get("__class__"), "xoutput_dict"
+                    )
+                    value[key] = class_obj(init_dict=obj)
+        if type(value) is int and value == -1:
+            value = dict()
+        check_var("xoutput_dict", value, "{DataKeeper}")
         self._xoutput_dict = value
 
     xoutput_dict = property(
@@ -594,7 +626,7 @@ class XOutput(Output):
         fset=_set_xoutput_dict,
         doc=u"""Dictionnary containing VarParam DataKeeper results in ndarray
 
-        :Type: dict
+        :Type: {DataKeeper}
         """,
     )
 
