@@ -4,8 +4,7 @@ from ....Methods.Simulation.Input import InputError
 
 
 def run(self):
-    """Run the Magnetics module    
-    """
+    """Run the Magnetics module"""
     if self.parent is None:
         raise InputError(
             "ERROR: The Magnetic object must be in a Simulation object to run"
@@ -15,7 +14,9 @@ def run(self):
             "ERROR: The Simulation object must be in an Output object to run"
         )
 
+    self.get_logger().info("Starting Magnetic module")
     output = self.parent.parent
 
     self.comp_time_angle(output)
+
     self.comp_flux_airgap(output)
